@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator;
-$DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.002225';
+$DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.002226';
 use Moo;
 
 # ABSTRACT: Manage your SQL and Perl migrations in nicely laid out directories
@@ -247,7 +247,9 @@ my %STORAGE2FEATURE = (
           push @ret, $accumulator;
           $accumulator = '';
         } else {
-          die "SQL splitting error: $accumulator $c (@ret)";
+          push @ret, $accumulator.$c;
+          $accumulator = '';
+          last;
         }
       }
       @ret;
